@@ -317,10 +317,10 @@ class TestBenchmark(unittest.TestCase):
         res = B.benchmark('some_weird_name', input_json)
         assert res is None
 
-    def test_benchmark_insulator_score_caller(self):
-        print("insulator-score-caller")
+    def test_benchmark_insulation_scores_and_boundaries_caller(self):
+        print("insulation-scores-and-boundaries-caller")
         input_json = {'input_size_in_bytes': {'mcoolfile': 32000000000}}
-        res = B.benchmark('insulator-score-caller', input_json)
+        res = B.benchmark('insulation-scores-and-boundaries-caller', input_json)
         print(res)
         assert 'aws' in res
         assert 'recommended_instance_type' in res['aws']
